summaryrefslogtreecommitdiff
path: root/sw/inc
diff options
context:
space:
mode:
authorMichael Stahl <mstahl@redhat.com>2015-08-20 13:40:59 +0200
committerMichael Stahl <mstahl@redhat.com>2015-08-20 14:17:51 +0200
commit8cf79b567010ff885da1f6a121a4e9b2ef96fccf (patch)
treeaed88dda5ea6911b68b64b051888d5801a42c4d7 /sw/inc
parent959a5043ccb4bb027e0149a56d31ebb78d5eb862 (diff)
tdf#93240: replace boost::ptr_vector with std::vector<std::unique_ptr>
Change-Id: I38f9140e565ab2a4d5dc7ad0c1d52837a5b5b67a
Diffstat (limited to 'sw/inc')
-rw-r--r--sw/inc/doc.hxx14
1 files changed, 6 insertions, 8 deletions
diff --git a/sw/inc/doc.hxx b/sw/inc/doc.hxx
index b9f803b076ce..1873a7d71577 100644
--- a/sw/inc/doc.hxx
+++ b/sw/inc/doc.hxx
@@ -55,8 +55,6 @@
#include <unordered_map>
#include <vector>
-#include <boost/ptr_container/ptr_vector.hpp>
-
namespace editeng { class SvxBorderLine; }
class SvxForbiddenCharactersTable;
@@ -235,7 +233,7 @@ namespace sfx2 {
class LinkManager;
}
-typedef boost::ptr_vector<SwPageDesc> SwPageDescs;
+typedef std::vector<std::unique_ptr<SwPageDesc>> SwPageDescs;
void SetAllScriptItem( SfxItemSet& rSet, const SfxPoolItem& rItem );
@@ -254,7 +252,7 @@ class SW_DLLPUBLIC SwDoc :
// private Member
std::unique_ptr<SwNodes> m_pNodes; //< document content (Nodes Array)
SwAttrPool* mpAttrPool; //< the attribute pool
- SwPageDescs maPageDescs; //< PageDescriptors
+ SwPageDescs m_PageDescs; //< PageDescriptors
Link<> maOle2Link; //< OLE 2.0-notification
/* @@@MAINTAINABILITY-HORROR@@@
Timer should not be members of the model
@@ -916,12 +914,12 @@ public:
sal_Int32 nDocPageCount );
// PageDescriptor interface.
- size_t GetPageDescCnt() const { return maPageDescs.size(); }
- const SwPageDesc& GetPageDesc( const size_t i ) const { return maPageDescs[i]; }
- SwPageDesc& GetPageDesc( size_t i ) { return maPageDescs[i]; }
+ size_t GetPageDescCnt() const { return m_PageDescs.size(); }
+ const SwPageDesc& GetPageDesc(const size_t i) const { return *m_PageDescs[i]; }
+ SwPageDesc& GetPageDesc(size_t const i) { return *m_PageDescs[i]; }
SwPageDesc* FindPageDesc(const OUString& rName, size_t* pPos = NULL);
SwPageDesc* FindPageDesc(const OUString& rName, size_t* pPos = NULL) const;
// Just searches the pointer in the maPageDescs vector!
bool ContainsPageDesc(const SwPageDesc *pDesc, size_t* pPos = NULL);
/** Copy the complete PageDesc - beyond document and "deep"!
@@ -916,12 +914,12 @@ public:
SwPageDesc* FindPageDesc(const OUString& rName, size_t* pPos = NULL);
SwPageDesc* FindPageDesc(const OUString& rName, size_t* pPos = NULL) const;
- // Just searches the pointer in the maPageDescs vector!
+ // Just searches the pointer in the m_PageDescs vector!
bool ContainsPageDesc(const SwPageDesc *pDesc, size_t* pPos = NULL);
/** Copy the complete PageDesc - beyond document and "deep"!